@@ -2,10 +2,10 @@ using System;
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-[assembly: ApplicationVersion ("1.7.2", "1.7.2")]
-[assembly: ApplicationBuildInformation ("git-checkout", "linux-gnu", "x86_64", "2010-06-30 20:23:01 EST")]
+[assembly: ApplicationVersion ("1.8.1", "1.8.1")]
+[assembly: ApplicationBuildInformation ("git-checkout", "linux-gnu", "x86_64", "2011-01-28 15:25:38 CST")]
 
-[assembly: AssemblyVersion ("1.7.0.0")]
+[assembly: AssemblyVersion ("1.8.0.0")]
 [assembly: AssemblyTitle ("Banshee")]
 [assembly: AssemblyDescription ("Banshee Media Player")]
 [assembly: AssemblyCopyright ("Copyright (C) 2005-2010 Novell Inc. and others")]
