@@ -67,8 +67,11 @@ namespace Nereid
         private HPaned views_pane;
         private ViewContainer view_container;
         private VBox source_box;
+        private Widget track_info_container;
         private CoverArtDisplay cover_art_display;
         private Widget cover_art_container;
+        private ConnectedSeekSlider seek_slider;
+        private TaskStatusIcon task_status;
 
         // Major Interaction Components
         private SourceView source_view;
@@ -92,6 +95,18 @@ namespace Nereid
         {
         }
 
+        private int? original_seek_width;
+        private void SetSimple (bool simple)
+        {
+            var widgets = new Widget [] { main_menu, source_box, footer_toolbar, track_info_container };
+            foreach (var w in widgets.Where (w => w != null)) {
+                w.Visible = !simple;
+            }
+
+            original_seek_width = original_seek_width ?? seek_slider.SeekSlider.WidthRequest;
+            seek_slider.SeekSlider.WidthRequest = original_seek_width.Value + (simple ? 100 : 0);
+        }
+
         public PlayerInterface () : base (Catalog.GetString ("Banshee Media Player"), "player_window", 1024, 700)
         {
             // if (PlatformDetection.IsMeeGo) {
@@ -186,7 +201,7 @@ namespace Nereid
 
             if (PlatformDetection.IsMeeGo) {
                 header_toolbar.IconSize = IconSize.LargeToolbar;
-                header_toolbar.Name = "moblin-toolbar";
+                header_toolbar.Name = "meego-toolbar";
             }
 
             toolbar_alignment.Add (header_toolbar);
@@ -200,15 +215,15 @@ namespace Nereid
             next_button.Show ();
             ActionService.PopulateToolbarPlaceholder (header_toolbar, "/HeaderToolbar/NextArrowButton", next_button);
 
-            ConnectedSeekSlider seek_slider = new ConnectedSeekSlider ();
+            seek_slider = new ConnectedSeekSlider ();
             seek_slider.Show ();
             ActionService.PopulateToolbarPlaceholder (header_toolbar, "/HeaderToolbar/SeekSlider", seek_slider);
 
             var track_info_display = new ClassicTrackInfoDisplay ();
             track_info_display.Show ();
-            var editable = TrackInfoDisplay.GetEditable (track_info_display);
-            editable.Show ();
-            ActionService.PopulateToolbarPlaceholder (header_toolbar, "/HeaderToolbar/TrackInfoDisplay", editable, true);
+            track_info_container = TrackInfoDisplay.GetEditable (track_info_display);
+            track_info_container.Show ();
+            ActionService.PopulateToolbarPlaceholder (header_toolbar, "/HeaderToolbar/TrackInfoDisplay", track_info_container, true);
 
             if (PlatformDetection.IsMeeGo) {
                 track_info_display.ArtworkSpacing = 5;
@@ -316,7 +331,7 @@ namespace Nereid
 
             footer_toolbar = new HBox () { BorderWidth = 2 };
 
-            Widget task_status = new Banshee.Gui.Widgets.TaskStatusIcon ();
+            task_status = new Banshee.Gui.Widgets.TaskStatusIcon ();
 
             EventBox status_event_box = new EventBox ();
             status_event_box.ButtonPressEvent += OnStatusBoxButtonPress;
@@ -429,6 +444,11 @@ namespace Nereid
                 view_container.SearchEntry.Ready = false;
                 view_container.SearchEntry.CancelSearch ();
 
+                /* Translators: this is a verb (command), not a noun (things) */
+                var msg = source.Properties.Get<string> ("SearchEntryDescription") ?? Catalog.GetString ("Search");
+                view_container.SearchEntry.EmptyMessage = msg;
+                view_container.SearchEntry.TooltipText = msg;
+
                 if (source.FilterQuery != null) {
                     view_container.SearchEntry.Query = source.FilterQuery;
                     view_container.SearchEntry.ActivateFilter ((int)source.FilterType);
@@ -459,6 +479,8 @@ namespace Nereid
 
                 UpdateSourceInformation ();
                 view_container.SearchEntry.Ready = true;
+
+                SetSimple (source.Properties.Get<bool> ("Nereid.SimpleUI"));
             });
         }
 
@@ -473,11 +495,17 @@ namespace Nereid
 
                 case "FilterQuery":
                     var source = ServiceManager.SourceManager.ActiveSource;
-                    ThreadAssist.ProxyToMain (delegate {
-                        view_container.SearchEntry.Ready = false;
-                        view_container.SearchEntry.Query = source.FilterQuery;
-                        view_container.SearchEntry.Ready = true;
-                    });
+                    var search_entry = source.Properties.Get<SearchEntry> ("Nereid.SearchEntry") ?? view_container.SearchEntry;
+                    if (!search_entry.HasFocus) {
+                        ThreadAssist.ProxyToMain (delegate {
+                            view_container.SearchEntry.Ready = false;
+                            view_container.SearchEntry.Query = source.FilterQuery;
+                            view_container.SearchEntry.Ready = true;
+                        });
+                    }
+                    break;
+                case "Nereid.SimpleUI":
+                    SetSimple (ServiceManager.SourceManager.ActiveSource.Properties.Get<bool> ("Nereid.SimpleUI"));
                     break;
             }
         }
@@ -626,8 +654,9 @@ namespace Nereid
                 }
             }
 
-            disable_keybindings &= ((GtkUtilities.NoImportantModifiersAreSet () &&
-                evnt.Key != Gdk.Key.Control_L && evnt.Key != Gdk.Key.Control_R));
+            // Don't disable them if ctrl is pressed
+            disable_keybindings &= (evnt.State & Gdk.ModifierType.ControlMask) == 0 &&
+                evnt.Key != Gdk.Key.Control_L && evnt.Key != Gdk.Key.Control_R;
 
             if (disable_keybindings) {
                 if (accel_group_active) {
@@ -666,8 +695,12 @@ namespace Nereid
                     break;
             }
 
-            if (focus_search && view_container.SearchEntry.Visible && !view_container.SearchEntry.HasFocus && !source_view.EditingRow) {
-                view_container.SearchEntry.HasFocus = true;
+            // The source might have its own custom search entry - use it if so
+            var src = ServiceManager.SourceManager.ActiveSource;
+            var search_entry = src.Properties.Get<SearchEntry> ("Nereid.SearchEntry") ?? view_container.SearchEntry;
+            if (focus_search && search_entry.Visible && !source_view.EditingRow) {
+                search_entry.InnerEntry.GrabFocus ();
+                search_entry.HasFocus = true;
                 return true;
             }
 
