@@ -230,11 +230,11 @@ namespace Banshee.Sources
             get { return DatabaseTrackModel.Count; }
         }
 
-        public TimeSpan Duration {
+        public virtual TimeSpan Duration {
             get { return DatabaseTrackModel.Duration; }
         }
 
-        public long FileSize {
+        public virtual long FileSize {
             get { return DatabaseTrackModel.FileSize; }
         }
 
@@ -308,10 +308,6 @@ namespace Banshee.Sources
             get { return true; }
         }
 
-        public override bool HasEditableTrackProperties {
-            get { return true; }
-        }
-
 #endregion
 
 #region Filters (aka Browsers)
